==> ejc-scientific-api-3.0.0-20250313.093249-57-sources.jar: com/ejianc/business/scientific/result/MethodApplyVO.java <==
package com.ejianc.business.scientific.result;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工法管理-工法申请
 * 
 * @author generator
 * 
 */
public class MethodApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // projectName
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // orgName
    private Long parentOrgId; // 父级组织(二级单位Id)
    private String parentOrgCode; // 父级组织编码(二级单位code)
    private String parentOrgName; // 父级组织(二级单位name)
    private Integer billState; // 单据状态（审批必须字段）

    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long deptId; // 经办部门
    private String deptName; // 经办部门名称
    private String methodName; // 工法名称
    private Integer methodType; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    private String methodTypeName; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    private Long methodPersonId; //  工法完成人id
    private String methodPersonName; //  工法完成人name
    private Long scientificProjectId; // 所属科研项目id
    private String scientificProjectName; // 所属科研项目name
    private String memo; // 备注
    private String billStateName; // 单据状态（审批必须字段）
    private Integer useStatus;


    public Integer getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(Integer useStatus) {
        this.useStatus = useStatus;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getMethodTypeName() {
        return methodTypeName;
    }

    public void setMethodTypeName(String methodTypeName) {
        this.methodTypeName = methodTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDeptId() {
        return deptId;
    }
    @ReferDeserialTransfer
    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getMethodName() {
        return methodName;
    }

    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    public Integer getMethodType() {
        return methodType;
    }

    public void setMethodType(Integer methodType) {
        this.methodType = methodType;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getMethodPersonId() {
        return methodPersonId;
    }
    @ReferDeserialTransfer
    public void setMethodPersonId(Long methodPersonId) {
        this.methodPersonId = methodPersonId;
    }
    public String getMethodPersonName() {
        return methodPersonName;
    }

    public void setMethodPersonName(String methodPersonName) {
        this.methodPersonName = methodPersonName;
    }
    @ReferSerialTransfer(referCode="sci-project")
    public Long getScientificProjectId() {
        return scientificProjectId;
    }
    @ReferDeserialTransfer
    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-scientific-api-3.0.0-20250415.102803-73-sources.jar: com/ejianc/business/scientific/result/MethodApplyVO.java <==
package com.ejianc.business.scientific.result;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工法管理-工法申请
 * 
 * @author generator
 * 
 */
public class MethodApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // projectName
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // orgName
    private Long parentOrgId; // 父级组织(二级单位Id)
    private String parentOrgCode; // 父级组织编码(二级单位code)
    private String parentOrgName; // 父级组织(二级单位name)
    private Integer billState; // 单据状态（审批必须字段）

    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long deptId; // 经办部门
    private String deptName; // 经办部门名称
    private String methodName; // 工法名称
    private Integer methodType; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    private String methodTypeName; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    private Long methodPersonId; //  工法完成人id
    private String methodPersonName; //  工法完成人name
    private Long scientificProjectId; // 所属科研项目id
    private String scientificProjectName; // 所属科研项目name
    private String memo; // 备注
    private String billStateName; // 单据状态（审批必须字段）
    private Integer useStatus;
    private String professionalClassification; // 专业分类
    private String mainTec; // 工法关键技术获得专利或科技成果奖励的情况
    private String techStandardStatus; //工法形成企业技术标准情况
    private String upgradedConstructionMethods; //（升级版工法填写此栏）原工法名称、完成单   位、省级工法批准文号及工法编号
    private String methodSummary; //工法内容简述
    private List<MethodApplyStatusVO> methodApplyStatusList;
    private List<MethodApplyPersonVO> methodApplyPersonEntityList;


    public Integer getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(Integer useStatus) {
        this.useStatus = useStatus;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getMethodTypeName() {
        return methodTypeName;
    }

    public void setMethodTypeName(String methodTypeName) {
        this.methodTypeName = methodTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDeptId() {
        return deptId;
    }
    @ReferDeserialTransfer
    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getMethodName() {
        return methodName;
    }

    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    public Integer getMethodType() {
        return methodType;
    }

    public void setMethodType(Integer methodType) {
        this.methodType = methodType;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getMethodPersonId() {
        return methodPersonId;
    }
    @ReferDeserialTransfer
    public void setMethodPersonId(Long methodPersonId) {
        this.methodPersonId = methodPersonId;
    }
    public String getMethodPersonName() {
        return methodPersonName;
    }

    public void setMethodPersonName(String methodPersonName) {
        this.methodPersonName = methodPersonName;
    }
    @ReferSerialTransfer(referCode="sci-project")
    public Long getScientificProjectId() {
        return scientificProjectId;
    }
    @ReferDeserialTransfer
    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getProfessionalClassification() {
        return professionalClassification;
    }

    public void setProfessionalClassification(String professionalClassification) {
        this.professionalClassification = professionalClassification;
    }

    public String getMainTec() {
        return mainTec;
    }

    public void setMainTec(String mainTec) {
        this.mainTec = mainTec;
    }

    public String getTechStandardStatus() {
        return techStandardStatus;
    }

    public void setTechStandardStatus(String techStandardStatus) {
        this.techStandardStatus = techStandardStatus;
    }

    public String getUpgradedConstructionMethods() {
        return upgradedConstructionMethods;
    }

    public void setUpgradedConstructionMethods(String upgradedConstructionMethods) {
        this.upgradedConstructionMethods = upgradedConstructionMethods;
    }

    public String getMethodSummary() {
        return methodSummary;
    }

    public void setMethodSummary(String methodSummary) {
        this.methodSummary = methodSummary;
    }

    public List<MethodApplyStatusVO> getMethodApplyStatusList() {
        return methodApplyStatusList;
    }

    public void setMethodApplyStatusList(List<MethodApplyStatusVO> methodApplyStatusList) {
        this.methodApplyStatusList = methodApplyStatusList;
    }

    public List<MethodApplyPersonVO> getMethodApplyPersonEntityList() {
        return methodApplyPersonEntityList;
    }

    public void setMethodApplyPersonEntityList(List<MethodApplyPersonVO> methodApplyPersonEntityList) {
        this.methodApplyPersonEntityList = methodApplyPersonEntityList;
    }
}
